/*
 *    This file is part of Linshare.
 *
 *   Linshare is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Affero General Public License as
 *   published by the Free Software Foundation, either version 3 of
 *   the License, or (at your option) any later version.
 *
 *   Linshare is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Affero General Public License for more details.
 *
 *   You should have received a copy of the GNU Affero General Public
 *   License along with Foobar.  If not, see
 *                                    <http://www.gnu.org/licenses/>.
 *
 *   (c) 2008 Groupe Linagora - http://linagora.org
 *
*/
package org.linagora.linshare.view.tapestry.components;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.StringTokenizer;

import org.apache.tapestry5.BindingConstants;
import org.apache.tapestry5.ComponentResources;
import org.apache.tapestry5.annotations.AfterRender;
import org.apache.tapestry5.annotations.Environmental;
import org.apache.tapestry5.annotations.Import;
import org.apache.tapestry5.annotations.InjectComponent;
import org.apache.tapestry5.annotations.Parameter;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.annotations.SetupRender;
import org.apache.tapestry5.annotations.SupportsInformalParameters;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.javascript.JavaScriptSupport;
import org.linagora.linshare.core.domain.vo.GuestDomainVo;
import org.linagora.linshare.core.domain.vo.UserVo;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.AbstractDomainFacade;
import org.linagora.linshare.core.facade.FunctionalityFacade;
import org.linagora.linshare.core.facade.UserFacade;
import org.linagora.linshare.view.tapestry.beans.ShareSessionObjects;
import org.linagora.linshare.view.tapestry.pages.user.Index;
import org.linagora.linshare.view.tapestry.services.BusinessMessagesManagementService;
import org.linagora.linshare.view.tapestry.services.Templating;
import org.linagora.linshare.view.tapestry.services.impl.MailCompletionService;
import org.linagora.linshare.view.tapestry.services.impl.PropertiesSymbolProvider;
import org.linagora.linshare.view.tapestry.utils.XSSFilter;
import org.owasp.validator.html.Policy;
import org.slf4j.Logger;

/** This component is used to create a new user.
 */
@SupportsInformalParameters
@Import(library = {"GuestEditForm.js"})
public class GuestEditForm {

	/* ***********************************************************
     *                         Parameters
     ************************************************************ */
	@Parameter(required = true, defaultPrefix = BindingConstants.PROP)
    @Property
    private List<UserVo> users;

	@Parameter(required = true, defaultPrefix = BindingConstants.PROP)
    @Property
    private String JSONid;
    /* ***********************************************************
     *                      Injected services
     ************************************************************ */
    @Inject
    private UserFacade userFacade;
    
    @Inject
    private AbstractDomainFacade domainFacade;

    @InjectComponent
    private Form guestCreateForm;
	
    @Inject
    private Messages messages;

    @Inject
    private Logger logger;

	@Inject
	private PropertiesSymbolProvider propertiesSymbolProvider;

	@Inject
	private Templating templating;
	
    @Inject
    private BusinessMessagesManagementService businessMessagesManagementService;


	/* ***********************************************************
     *                Properties & injected symbol, ASO, etc
     ************************************************************ */
    @SessionState
    @Property
    private UserVo userLoggedIn;

    @SessionState
    private ShareSessionObjects shareSessionObjects;
    
	@Environmental
	private JavaScriptSupport renderSupport;

    @Property
    private String mail;

    @Property
    private String firstName;

    @Property
    private String lastName;

//    @Property
//    private boolean uploadGranted;
	
	@Property
	private boolean guestsAllowedToCreateGuest;
    
    @Property
    private boolean restrictedGuest;

    @Property
    private String customMessage;

    @Property
    private String comment;
	
	
	@Persist("flash")
	private List<String> recipientsEmail;
	
	@Persist("flash")
	@Property
	private String recipientsSearch;

    private boolean userAlreadyExists = false;

    @Inject
    private ComponentResources componentResources;
    
    @Property
	private int autocompleteMin;
	
	@Inject
	private FunctionalityFacade functionalityFacade;
	
	@Property
	private boolean showRestricted;
	
	
	private XSSFilter filter;

	@Inject
	private Policy antiSamyPolicy;
	

	@SetupRender
	void init() throws BusinessException {
		recipientsSearch = MailCompletionService.formatLabel(userLoggedIn);
		
    	GuestDomainVo guestDomainVo = domainFacade.findGuestDomain(userLoggedIn.getDomainIdentifier());
    	if (guestDomainVo != null){
    		showRestricted = functionalityFacade.isRestrictedGuestEnabled(userLoggedIn.getDomainIdentifier());
			restrictedGuest = functionalityFacade.getDefaultRestrictedGuestValue(userLoggedIn.getDomainIdentifier()) || userLoggedIn.isRestricted();
    	}
    	
		guestsAllowedToCreateGuest = false;
		autocompleteMin = functionalityFacade.completionThreshold(userLoggedIn.getDomainIdentifier());
	}
	
	@AfterRender
	void afterRender() {
		renderSupport.addScript("initAllowedContacts("+Boolean.toString(restrictedGuest)+");");
	}

	public List<String> onProvideCompletionsFromRecipientsPatternGuestForm(String input) throws BusinessException {
		List<UserVo> searchResults = performSearch(input);

		List<String> elements = new ArrayList<String>();
		for (UserVo user : searchResults) {
			 String completeName = MailCompletionService.formatLabel(user);
            if (!elements.contains(completeName)) {
                elements.add(completeName);
            }
		}

		return elements;
	}
	
	/** Perform a user search using the user search pattern.
	 * @param input user search pattern.
	 * @return list of users.
	 * @throws BusinessException 
	 */
	private List<UserVo> performSearch(String input) throws BusinessException {


		Set<UserVo> userSet = new HashSet<UserVo>();

		String firstName_ = null;
		String lastName_ = null;

		if (input != null && input.length() > 0) {
			StringTokenizer stringTokenizer = new StringTokenizer(input, " ");
			if (stringTokenizer.hasMoreTokens()) {
				firstName_ = stringTokenizer.nextToken();
				if (stringTokenizer.hasMoreTokens()) {
					lastName_ = stringTokenizer.nextToken();
				}
			}
		}

//        if (input != null) {
//            userSet.addAll(userFacade.searchUserForRestrictedGuestEditionForm(input.trim(), null, null, mail));
//        }
//		userSet.addAll(userFacade.searchUserForRestrictedGuestEditionForm(null, firstName_, lastName_, mail));
//		userSet.addAll(userFacade.searchUserForRestrictedGuestEditionForm(null, lastName_, firstName_,  mail));
		
		
		if (input != null) {
			userSet.addAll(userFacade.searchUser(input.trim(), null, null,userLoggedIn));
		}
		userSet.addAll(userFacade.searchUser(null, firstName_, lastName_, userLoggedIn));
		userSet.addAll(userFacade.searchUser(null, lastName_, firstName_,  userLoggedIn));
		
		return new ArrayList<UserVo>(userSet);
	}
	

    /* ***********************************************************
     *                   Event handlers&processing
     ************************************************************ */
	
    public void  onValidateFormFromGuestCreateForm() throws BusinessException {
    	
    	if (guestCreateForm.getHasErrors()) {
    		return ;
    	}
    	
    	if (mail == null | firstName == null | lastName == null) {
    		// the message will be handled by Tapestry
    		return;
    	}

    	GuestDomainVo guestDomainVo = domainFacade.findGuestDomain(userLoggedIn.getDomainIdentifier());
    	
        if (userFacade.findUserInDb(mail, userLoggedIn.getDomainIdentifier()) != null || userFacade.findUserInDb(mail, guestDomainVo.getIdentifier()) != null ) {
            guestCreateForm.recordError(messages.get("pages.user.edit.error.alreadyExist"));
            shareSessionObjects.addError(messages.get("pages.user.edit.error.alreadyExist"));
            userAlreadyExists = true;
            return ;
        }
        
		
    	if (restrictedGuest || userLoggedIn.isRestricted()) {
        	boolean sendErrors = false;
        	
	    	List<String> recipients = MailCompletionService.parseEmails(recipientsSearch);
	    	String badFormatEmail =  "";
			
	    	for (String recipient : recipients) {
	        	if (!MailCompletionService.MAILREGEXP.matcher(recipient.toUpperCase()).matches()){
	            	badFormatEmail = badFormatEmail + recipient + " ";
	            	sendErrors = true;
	            }
	    	}
			
	    	if(sendErrors) {
	        	guestCreateForm.recordError(String.format(messages.get("components.confirmSharePopup.validate.email"), badFormatEmail));
	        }
	    	else {
	        	this.recipientsEmail = recipients;
	        }
    	}
    }

    Object onSuccess() {
		filter = new XSSFilter(shareSessionObjects, guestCreateForm, antiSamyPolicy, messages);
		try {
			mail = filter.clean(mail);
			firstName = filter.clean(firstName);
			lastName = filter.clean(lastName);
			comment = filter.clean(comment);
			customMessage = filter.clean(customMessage);
			if (filter.hasError()) {
				logger.debug("XSSFilter found some tags and striped them.");
				businessMessagesManagementService.notify(filter.getWarningMessage());
			}
		} catch (BusinessException e) {
			logger.debug(e.toString());
			businessMessagesManagementService.notify(e);
			businessMessagesManagementService.notify(e);
			return Index.class;
		}
		
		UserVo guestVo = null ;
		try {
			// set uploadGranted always to true for guest
			boolean uploadGranted = true;

			boolean allowedToCreateGuest = guestsAllowedToCreateGuest;
        	
        	guestVo = userFacade.createGuest(mail, firstName, lastName, uploadGranted, allowedToCreateGuest, comment, userLoggedIn);
		} catch (BusinessException e) { 
			logger.error("Can't create Guest : " + mail);
			logger.debug(e.toString());
			businessMessagesManagementService.notify(e);
			return Index.class;
		}
        	
        try {
        	if (userLoggedIn.isRestricted()) { //user restricted needs to see the guest he has created
        		userFacade.addGuestContactRestriction(userLoggedIn.getLsUid(), guestVo.getLsUid());
        	}
        	
        	if (restrictedGuest || userLoggedIn.isRestricted()) { // a restricted guest can only create restricted guests
        		userFacade.setGuestContactRestriction(guestVo.getLsUid(), recipientsEmail);
        	}
            shareSessionObjects.addMessage(messages.get("components.guestEditForm.action.add.confirm"));
        } catch (BusinessException e) { //bad contact for contacts list
        	logger.debug(e.toString());
        	shareSessionObjects.addError(messages.get("components.guestEditForm.action.add.guestRestriction.badUser"));
        	List<String> contactMailList = new ArrayList<String>();
        	contactMailList.add(userLoggedIn.getMail());
        	try {
				userFacade.setGuestContactRestriction(guestVo.getLsUid(), contactMailList); //default: set guest contact restriction with the owner
			} catch (BusinessException e1) {
				e1.printStackTrace();
			}
        }
        componentResources.triggerEvent("resetListUsers", null, null);
        
        return Index.class;
    }

    Object onFailure() {
    	if (!userAlreadyExists)
    		shareSessionObjects.addError(messages.get("pages.user.edit.error.generic"));
    	return this;
    }
  
}
